# Generated by roxygen2: do not edit by hand

export(CONES)
export(EQ_DIM)
export(EXP)
export(EXP_DUAL)
export(POS)
export(PSD)
export(SOC)
export(ZERO)
export(parse_cone_dict)
export(pi)
export(solve_and_derivative)
export(solve_only)
export(unvec_symm)
export(upstream_info)
export(vec_symm)
import(Matrix)
importFrom(Rcpp,evalCpp)
useDynLib(diffcp, .registration = TRUE)
