# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

cpp_dprojection_dense <- function(x, cones_R, dual) {
    .Call(`_diffcp_cpp_dprojection_dense`, x, cones_R, dual)
}

cpp_M_dense <- function(Q_dense, cones_R, u, v, w) {
    .Call(`_diffcp_cpp_M_dense`, Q_dense, cones_R, u, v, w)
}

cpp_solve_derivative_dense <- function(M, MT, rhs) {
    .Call(`_diffcp_cpp_solve_derivative_dense`, M, MT, rhs)
}

cpp_solve_adjoint_derivative_dense <- function(M, MT, dz) {
    .Call(`_diffcp_cpp_solve_adjoint_derivative_dense`, M, MT, dz)
}

cpp_lsqr_M <- function(Q, cones_R, u, v, w, rhs, transpose, damp = 0.0, atol = 1e-8, btol = 1e-8, conlim = 1e8, iter_lim = -1L) {
    .Call(`_diffcp_cpp_lsqr_M`, Q, cones_R, u, v, w, rhs, transpose, damp, atol, btol, conlim, iter_lim)
}

cpp_lsqr_sparse <- function(A, b, damp = 0.0, atol = 1e-8, btol = 1e-8, conlim = 1e8, iter_lim = -1L) {
    .Call(`_diffcp_cpp_lsqr_sparse`, A, b, damp, atol, btol, conlim, iter_lim)
}

cpp_project_exp_cone <- function(x) {
    .Call(`_diffcp_cpp_project_exp_cone`, x)
}

cpp_in_exp <- function(x) {
    .Call(`_diffcp_cpp_in_exp`, x)
}

cpp_in_exp_dual <- function(x) {
    .Call(`_diffcp_cpp_in_exp_dual`, x)
}

