% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cones.R
\name{pi}
\alias{pi}
\title{Projection onto a Cartesian product of cones}
\usage{
pi(x, cones, dual = FALSE)
}
\arguments{
\item{x}{A numeric vector.}

\item{cones}{A list of \code{list(name, size)} pairs, as produced by
\code{parse_cone_dict}.}

\item{dual}{If \code{TRUE}, project onto the dual cones.}
}
\value{
A numeric vector of the same length as \code{x}.
}
\description{
Mirrors \code{diffcp.cones.pi}.
}
