% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cones.R
\name{parse_cone_dict}
\alias{parse_cone_dict}
\title{Parse an SCS-style cone dictionary into an ordered list}
\usage{
parse_cone_dict(cone_dict)
}
\arguments{
\item{cone_dict}{A named list with keys among \code{"z"}, \code{"l"}, \code{"q"},
\code{"s"}, \code{"ep"}, \code{"ed"}. Values are scalar dimensions (for \code{z}, \code{l},
\code{ep}, \code{ed}) or integer vectors of dimensions (for \code{q}, \code{s}).}
}
\value{
A list of \code{list(name, size)} pairs, in the canonical SCS
cone order (\code{CONES}).
}
\description{
Mirrors \code{diffcp.cones.parse_cone_dict}.
}
